{
    "$graph": [
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "Expression threshold for displaying target genes on a plot (expression > threshold)",
                    "id": "#soupx-subworkflow.cwl/expression_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "doc": "FDR cutoff for expression ratio plots",
                    "id": "#soupx-subworkflow.cwl/fdr"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with filtered feature-barcode matrices",
                    "id": "#soupx-subworkflow.cwl/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Target genes list. Headerless text file with 1 gene per line",
                    "id": "#soupx-subworkflow.cwl/genelist_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version",
                            "symbols": [
                                "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version/2",
                                "#soupx-subworkflow.cwl/matrix_format_version/matrix_format_version/3"
                            ]
                        }
                    ],
                    "doc": "Output matrix format version. Corresponds to the latest Cell Ranger matrix format",
                    "id": "#soupx-subworkflow.cwl/matrix_format_version"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "doc": "Output prefix",
                    "id": "#soupx-subworkflow.cwl/output_prefix"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with unfiltered feature-barcode matrices",
                    "id": "#soupx-subworkflow.cwl/raw_feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "doc": "Round adjusted counts to integers",
                    "id": "#soupx-subworkflow.cwl/round_counts"
                },
                {
                    "type": "File",
                    "doc": "Compressed folder with secondary analysis results",
                    "id": "#soupx-subworkflow.cwl/secondary_analysis_report_folder"
                }
            ],
            "steps": [
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_folder",
                            "id": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/compressed_folder"
                    ],
                    "id": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder"
                },
                {
                    "run": "#soupx.cwl",
                    "in": [
                        {
                            "source": "#soupx-subworkflow.cwl/expression_threshold",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/expression_threshold"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/fdr",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/fdr"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/output_folder",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/feature_bc_matrices_folder"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/genelist_file",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/genelist_file"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/matrix_format_version",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/matrix_format_version"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/output_prefix",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/output_prefix"
                        },
                        {
                            "source": "#soupx-subworkflow.cwl/round_counts",
                            "id": "#soupx-subworkflow.cwl/estimate_contamination/round_counts"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_folder",
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_h5",
                        "#soupx-subworkflow.cwl/estimate_contamination/contamination_estimation_plot",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/adjusted_gene_expression_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                        "#soupx-subworkflow.cwl/estimate_contamination/stdout_log",
                        "#soupx-subworkflow.cwl/estimate_contamination/stderr_log"
                    ],
                    "id": "#soupx-subworkflow.cwl/estimate_contamination"
                },
                {
                    "run": {
                        "cwlVersion": "v1.0",
                        "class": "CommandLineTool",
                        "hints": [
                            {
                                "class": "DockerRequirement",
                                "dockerPull": "scidap/scidap:v0.0.4"
                            }
                        ],
                        "inputs": [
                            {
                                "type": {
                                    "type": "array",
                                    "items": "File"
                                },
                                "inputBinding": {
                                    "position": 2
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/9c03a53f-5693-4531-8991-77268457b52b/compressed_files"
                            },
                            {
                                "type": [
                                    "null",
                                    "string"
                                ],
                                "default": "set -- \"$0\" \"$@\"\nmkdir counts && cd counts\nfor i in \"$@\";\n    do tar xvf $i;\ndone;\n",
                                "inputBinding": {
                                    "position": 1
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/9c03a53f-5693-4531-8991-77268457b52b/script"
                            }
                        ],
                        "outputs": [
                            {
                                "type": "Directory",
                                "outputBinding": {
                                    "glob": "counts"
                                },
                                "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/9c03a53f-5693-4531-8991-77268457b52b/output_folder"
                            }
                        ],
                        "baseCommand": [
                            "bash",
                            "-c"
                        ],
                        "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/9c03a53f-5693-4531-8991-77268457b52b"
                    },
                    "in": [
                        {
                            "source": [
                                "#soupx-subworkflow.cwl/raw_feature_bc_matrices_folder",
                                "#soupx-subworkflow.cwl/filtered_feature_bc_matrix_folder",
                                "#soupx-subworkflow.cwl/secondary_analysis_report_folder"
                            ],
                            "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/compressed_files"
                        }
                    ],
                    "out": [
                        "#soupx-subworkflow.cwl/extract_count_matrices_to_folder/output_folder"
                    ],
                    "id": "#soupx-subworkflow.cwl/extract_count_matrices_to_folder"
                }
            ],
            "label": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "doc": "Wrapped in a workflow SoupX tool for easy access to Cell Ranger pipeline compressed outputs.\n",
            "id": "#soupx-subworkflow.cwl",
            "http://schema.org/name": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/alternateName": "SoupX (workflow) - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/soupx-subworkflow.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Wrapped in a workflow SoupX tool for easy access to Cell Ranger pipeline compressed outputs.",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/compress_adjusted_feature_bc_matrices_folder/compressed_folder",
                    "doc": "Compressed folder with adjusted feature-barcode matrices in MEX format",
                    "id": "#soupx-subworkflow.cwl/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_feature_bc_matrices_h5",
                    "doc": "Adjusted feature-barcode matrices in HDF5 format",
                    "id": "#soupx-subworkflow.cwl/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/adjusted_gene_expression_plots",
                    "doc": "Adjusted gene expression plots",
                    "id": "#soupx-subworkflow.cwl/adjusted_gene_expression_plots"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/contamination_estimation_plot",
                    "doc": "Contamination estimation plot",
                    "id": "#soupx-subworkflow.cwl/contamination_estimation_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_plots",
                    "doc": "Raw gene expression plots",
                    "id": "#soupx-subworkflow.cwl/raw_gene_expression_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                    "doc": "Raw gene expression to pure soup ratio plots",
                    "id": "#soupx-subworkflow.cwl/raw_gene_expression_to_pure_soup_ratio_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                    "doc": "Raw to adjusted gene expression ratio plots",
                    "id": "#soupx-subworkflow.cwl/raw_to_adjusted_gene_expression_ratio_plots"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/stderr_log",
                    "doc": "SoupX stderr log",
                    "id": "#soupx-subworkflow.cwl/soupx_stderr_log"
                },
                {
                    "type": "File",
                    "outputSource": "#soupx-subworkflow.cwl/estimate_contamination/stdout_log",
                    "doc": "SoupX stdout log",
                    "id": "#soupx-subworkflow.cwl/soupx_stdout_log"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/soupx:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--threshold"
                    },
                    "doc": "Expression threshold for displaying target genes on a plot (expression > threshold)\nDefault: 0.0\n",
                    "id": "#soupx.cwl/expression_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--fdr"
                    },
                    "doc": "FDR cutoff for expression ratio plots\nDefault: 0.05\n",
                    "id": "#soupx.cwl/fdr"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "--counts"
                    },
                    "doc": "Path to the output folder produced by 'cellranger count' command\n",
                    "id": "#soupx.cwl/feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "prefix": "--genes"
                    },
                    "doc": "Path to the file with target genes (headerless, one gene per line)\n",
                    "id": "#soupx.cwl/genelist_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#soupx.cwl/matrix_format_version/matrix_format_version",
                            "symbols": [
                                "#soupx.cwl/matrix_format_version/matrix_format_version/2",
                                "#soupx.cwl/matrix_format_version/matrix_format_version/3"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "--format"
                    },
                    "doc": "Output matrix format version. Corresponds to the latest Cell Ranger matrix format\nDefault: 3\n",
                    "id": "#soupx.cwl/matrix_format_version"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "--output"
                    },
                    "doc": "Output prefix\nDefault: soupx\n",
                    "id": "#soupx.cwl/output_prefix"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--round"
                    },
                    "doc": "Round adjusted counts to integers\nDefault: False\n",
                    "id": "#soupx.cwl/round_counts"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "*adjusted_counts"
                    },
                    "doc": "Folder with adjusted feature-barcode matrices in MEX format\n",
                    "id": "#soupx.cwl/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*adjusted_counts.h5"
                    },
                    "doc": "Adjusted feature-barcode matrices in HDF5 format\n",
                    "id": "#soupx.cwl/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*adjusted_gene_expression_plots.pdf"
                    },
                    "doc": "Adjusted gene expression plots\n",
                    "id": "#soupx.cwl/adjusted_gene_expression_plots"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*contamination_estimation_plot.pdf"
                    },
                    "doc": "Contamination estimation plot\n",
                    "id": "#soupx.cwl/contamination_estimation_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_gene_expression_plots.pdf"
                    },
                    "doc": "Raw gene expression plots\n",
                    "id": "#soupx.cwl/raw_gene_expression_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_gene_expression_to_pure_soup_ratio_plots.pdf"
                    },
                    "doc": "Raw gene expression to pure soup ratio plots\n",
                    "id": "#soupx.cwl/raw_gene_expression_to_pure_soup_ratio_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "*raw_to_adjusted_gene_expression_ratio_plots.pdf"
                    },
                    "doc": "Raw to adjusted gene expression ratio plots\n",
                    "id": "#soupx.cwl/raw_to_adjusted_gene_expression_ratio_plots"
                },
                {
                    "type": "File",
                    "id": "#soupx.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "soupx_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#soupx.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "soupx_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "run_soupx.R"
            ],
            "stdout": "soupx_stdout.log",
            "stderr": "soupx_stderr.log",
            "label": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "doc": "In droplet based, single cell RNA-seq experiments, there is always a certain amount of background\nmRNAs present in the dilution that gets distributed into the droplets with cells and sequenced\nalong with them. The net effect of this is to produce a background contamination that represents\nexpression not from the cell contained within a droplet, but the solution that contained the cells.\n\nThis collection of cell free mRNAs floating in the input solution (henceforth referred to as\n\u201cthe soup\u201d) is created from cells in the input solution being lysed. Because of this, the soup looks\ndifferent for each input solution and strongly resembles the expression pattern obtained by summing\nall the individual cells.\n\nThe aim of this package is to provide a way to estimate the composition of this soup, what fraction\nof UMIs are derived from the soup in each droplet and produce a corrected count table with the soup\nbased expression removed.\n\nThe method to do this consists of three parts:\n\n- Calculate the profile of the soup.\n- Estimate the cell specific contamination fraction.\n- Infer a corrected expression matrix.  \n",
            "id": "#soupx.cwl",
            "http://schema.org/name": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/alternateName": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/soupx.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: run_soupx.R [-h] --counts COUNTS [--genes GENES]\n                                  [--threshold THRESHOLD] [--fdr FDR]\n                                  [--round] [--format {2,3}] [--output OUTPUT]\n\nRuns SoupX - an R package for the estimation and removal of cell free mRNA\ncontamination\n\noptional arguments:\n  -h, --help            show this help message and exit\n  --counts COUNTS       Path to the output folder produced by 'cellranger\n                        count' command\n  --genes GENES         Path to the file with target genes (headerless, one\n                        gene per line)\n  --threshold THRESHOLD\n                        Expression threshold for displaying target genes on a\n                        plot (expression > threshold). Default: 0.0\n  --fdr FDR             FDR cutoff for expression ratio plots. Default: 0.05\n  --round               Round adjusted counts to integers\n  --format {2,3}        Output matrix format version. Default: 3 (corresponds\n                        to the latest Cell Ranger matrix format)\n  --output OUTPUT       Output prefix. Default: soupx"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Folder to compressed",
                    "id": "#tar-compress.cwl/folder_to_compress"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Compressed folder",
                    "id": "#tar-compress.cwl/compressed_folder"
                }
            ],
            "baseCommand": [
                "tar"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.folder_to_compress.path.split(\"/\").slice(0,-1).join(\"/\"))",
                    "prefix": "-C"
                },
                "-czvf",
                {
                    "valueFrom": "$(inputs.folder_to_compress.basename + \".tar.gz\")"
                },
                "."
            ],
            "doc": "Compresses input directory to tar.gz\n",
            "id": "#tar-compress.cwl",
            "http://schema.org/name": "tar-compress",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/tar-compress.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "sc_rnaseq_sample": [
                    "single-cell-preprocess-cellranger.cwl",
                    "cellranger-aggr.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0,
                    "label": "Expression threshold for displaying target genes on a plot (expression > threshold)",
                    "doc": "Expression threshold for displaying target genes on a plot (expression > threshold)",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/expression_threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "default": 0.05,
                    "label": "FDR cutoff for expression ratio plots",
                    "doc": "FDR cutoff for expression ratio plots",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/fdr"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3989",
                    "label": "scRNA-Seq Cell Ranger Experiment",
                    "doc": "Compressed folder with filtered feature-barcode matrices",
                    "sd:upstreamSource": "sc_rnaseq_sample/filtered_feature_bc_matrix_folder",
                    "sd:localLabel": true,
                    "id": "#main/filtered_feature_bc_matrix_folder"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "Target genes list. Headerless text file with 1 gene per line",
                    "doc": "Target genes list. Headerless text file with 1 gene per line",
                    "id": "#main/genelist_file"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3989",
                    "label": "scRNA-Seq Cell Ranger Experiment",
                    "doc": "Compressed folder with unfiltered feature-barcode matrices",
                    "sd:upstreamSource": "sc_rnaseq_sample/raw_feature_bc_matrices_folder",
                    "sd:localLabel": true,
                    "id": "#main/raw_feature_bc_matrices_folder"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Round adjusted counts to integers",
                    "doc": "Round adjusted counts to integers",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/round_counts"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3989",
                    "label": "scRNA-Seq Cell Ranger Experiment",
                    "doc": "Compressed folder with secondary analysis results",
                    "sd:upstreamSource": "sc_rnaseq_sample/secondary_analysis_report_folder",
                    "sd:localLabel": true,
                    "id": "#main/secondary_analysis_report_folder"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3989",
                    "outputSource": "#main/estimate_contamination/adjusted_feature_bc_matrices_folder",
                    "label": "Compressed folder with adjusted feature-barcode matrices in MEX format",
                    "doc": "Compressed folder with adjusted feature-barcode matrices in MEX format",
                    "id": "#main/adjusted_feature_bc_matrices_folder"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3590",
                    "outputSource": "#main/estimate_contamination/adjusted_feature_bc_matrices_h5",
                    "label": "Adjusted feature-barcode matrices in HDF5 format",
                    "doc": "Adjusted feature-barcode matrices in HDF5 format",
                    "id": "#main/adjusted_feature_bc_matrices_h5"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "outputSource": "#main/estimate_contamination/adjusted_gene_expression_plots",
                    "label": "Adjusted gene expression plots",
                    "doc": "Adjusted gene expression plots",
                    "id": "#main/adjusted_gene_expression_plots"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3508",
                    "outputSource": "#main/estimate_contamination/contamination_estimation_plot",
                    "label": "Contamination estimation plot",
                    "doc": "Contamination estimation plot",
                    "id": "#main/contamination_estimation_plot"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "outputSource": "#main/estimate_contamination/raw_gene_expression_plots",
                    "label": "Raw gene expression plots",
                    "doc": "Raw gene expression plots",
                    "id": "#main/raw_gene_expression_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "outputSource": "#main/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                    "label": "Raw gene expression to pure soup ratio plots",
                    "doc": "Raw gene expression to pure soup ratio plots",
                    "id": "#main/raw_gene_expression_to_pure_soup_ratio_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_3508",
                    "outputSource": "#main/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                    "doc": "Raw to adjusted gene expression ratio plots",
                    "id": "#main/raw_to_adjusted_gene_expression_ratio_plots"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/estimate_contamination/soupx_stderr_log",
                    "label": "SoupX stderr log",
                    "doc": "SoupX stderr log",
                    "id": "#main/soupx_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "outputSource": "#main/estimate_contamination/soupx_stdout_log",
                    "label": "SoupX stdout log",
                    "doc": "SoupX stdout log",
                    "id": "#main/soupx_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#soupx-subworkflow.cwl",
                    "in": [
                        {
                            "source": "#main/expression_threshold",
                            "id": "#main/estimate_contamination/expression_threshold"
                        },
                        {
                            "source": "#main/fdr",
                            "id": "#main/estimate_contamination/fdr"
                        },
                        {
                            "source": "#main/filtered_feature_bc_matrix_folder",
                            "id": "#main/estimate_contamination/filtered_feature_bc_matrix_folder"
                        },
                        {
                            "source": "#main/genelist_file",
                            "id": "#main/estimate_contamination/genelist_file"
                        },
                        {
                            "source": "#main/raw_feature_bc_matrices_folder",
                            "id": "#main/estimate_contamination/raw_feature_bc_matrices_folder"
                        },
                        {
                            "source": "#main/round_counts",
                            "id": "#main/estimate_contamination/round_counts"
                        },
                        {
                            "source": "#main/secondary_analysis_report_folder",
                            "id": "#main/estimate_contamination/secondary_analysis_report_folder"
                        }
                    ],
                    "out": [
                        "#main/estimate_contamination/adjusted_feature_bc_matrices_folder",
                        "#main/estimate_contamination/adjusted_feature_bc_matrices_h5",
                        "#main/estimate_contamination/contamination_estimation_plot",
                        "#main/estimate_contamination/raw_gene_expression_plots",
                        "#main/estimate_contamination/adjusted_gene_expression_plots",
                        "#main/estimate_contamination/raw_gene_expression_to_pure_soup_ratio_plots",
                        "#main/estimate_contamination/raw_to_adjusted_gene_expression_ratio_plots",
                        "#main/estimate_contamination/soupx_stdout_log",
                        "#main/estimate_contamination/soupx_stderr_log"
                    ],
                    "id": "#main/estimate_contamination"
                }
            ],
            "label": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "doc": "Devel version of Single-Cell Advanced Cell Ranger Pipeline (SoupX)\n=================================================================\n",
            "id": "#main",
            "http://schema.org/name": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/alternateName": "SoupX - an R package for the estimation and removal of cell free mRNA contamination",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/soupx.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://schema.org/version/9.0/schemaorg-current-http.rdf",
        "http://schema.org/docs/schema_org_rdfa.html"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
